# ##### BEGIN GPL LICENSE BLOCK #####
#
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software Foundation,
#  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# ##### END GPL LICENSE BLOCK #####

# <pep8 compliant>

import re
import xml.dom.minidom
import bpy
import bmesh
import code


def load_LandXML_points(filepath):
#parse the LandXML file
    node = xml.dom.minidom.parse(filepath)

    scene = bpy.context.scene
    scene.update()
    
    if bpy.ops.object.mode_set.poll():
        print('in load_XML mode_set = OBJECT')
        bpy.ops.object.mode_set(mode='OBJECT')
        

# Create the new mesh to feed in vertices:
    scene = bpy.context.scene
    mesh = bpy.data.meshes.new('')
    object = bpy.data.objects.new('LandXML vertices', mesh)
    scene.objects.link(object)

# Read in all points
    points=node.getElementsByTagName('CgPoint')

    r=mesh.vertices
    r.add(len(points))
    idx=0
    for p in points:
        for coordset in p.childNodes:
            xyz_list=coordset.data.strip()
            xyz_coord=xyz_list.split(' ')
            x_coord=0
            y_coord=0
            z_coord=0
            if len(xyz_coord) == 3:
                x_coord=float(xyz_coord[1])
                y_coord=float(xyz_coord[0])
                z_coord=float(xyz_coord[2])
#            operator.report({'WARNING'}, "read in vtx %f %f %f" % (x_coord,y_coord,z_coord))
            coord=(x_coord, y_coord, z_coord)
            r[idx].co=coord
            idx=idx+1

        
    scene.update()
    mesh.update() 
    object.select=True
    bpy.ops.object.origin_set(type='ORIGIN_GEOMETRY', center='MEDIAN')
    scene.update()
    return None



def load(operator, context, filepath=""):

    try:
        load_LandXML_points(filepath)
    except (xml.parsers.expat.ExpatError, UnicodeEncodeError) as e:
        import traceback
        traceback.print_exc()

        operator.report({'WARNING'}, "Unable to parse XML, %s:%s for file %r" % (type(e).__name__, e, filepath))
        return {'CANCELLED'}

    return {'FINISHED'}