# ##### BEGIN GPL LICENSE BLOCK #####
#
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software Foundation,
#  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# ##### END GPL LICENSE BLOCK #####

bl_info = {
    "name": "Import LandXML Points",
    "author": "",
    "version": (0, 1),
    "blender": (2, 7, 2),
    "location": "File > Import-Export > LandXML Points",
    "description": "Imports LandXML Points.",
    "warning": "",
    "wiki_url": "",
    "tracker_url": "",
#    "support": '',
    "category": "Import-Export"}


if "bpy" in locals():
    import imp
    imp.reload(import_LandXML_points)
else:
    from . import import_LandXML_points

import itertools
import os


import bpy
from bpy.props import *
from bpy_extras.io_utils import ExportHelper, ImportHelper


class ImportLandXMLPoints(bpy.types.Operator, ImportHelper):
  
    bl_idname = "import_landxml_points.xml"
    bl_label = "Import LandXML Points"

    filename_ext = ".xml"

    filter_glob = StringProperty(default="*.xml", options={'HIDDEN'})

    files = CollectionProperty(name="File Path",
                          description="File path used for importing "
                                      "the LandXML file",
                          type=bpy.types.OperatorFileListElement)

    directory = StringProperty(subtype='DIR_PATH')

    def execute(self, context):
        paths = [os.path.join(self.directory, name.name) for name in self.files]
        if not paths:
            paths.append(self.filepath)

        for path in paths:
            import_LandXML_points.load_LandXML_points(path)

        return {'FINISHED'}



def menu_func_import(self, context):
    self.layout.operator(ImportLandXMLPoints.bl_idname, text="LandXML Points (.xml)", icon='PLUGIN').filepath = "*.xml"


def menu_func_export(self, context):

    pass


def register():
    bpy.utils.register_module(__name__)

    bpy.types.INFO_MT_file_import.append(menu_func_import)
    bpy.types.INFO_MT_file_export.append(menu_func_export)


def unregister():
    bpy.utils.unregister_module(__name__)

    bpy.types.INFO_MT_file_import.remove(menu_func_import)
    bpy.types.INFO_MT_file_export.remove(menu_func_export)


if __name__ == "__main__":
    register()

