# ##### BEGIN GPL LICENSE BLOCK #####
#
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software Foundation,
#  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# ##### END GPL LICENSE BLOCK #####

# <pep8 compliant>

import re
import xml.dom.minidom
import bpy
import bmesh
import code

def cleanup(sce, ob, d_verts):
#Need to cleanup the left over vertices from 
#mesh creation
    sce.update()
    bpy.context.scene.objects.active=ob
    ob.select=True
    me=ob.data
    print(me)
    if bpy.ops.object.mode_set.poll():
        print('mode_set = OBJECT')
        bpy.ops.object.mode_set(mode='OBJECT')
    q=[]
    d=[]
    for p in me.vertices:
        q.append(p.index)
        
#Using sets to find the unused vertices
#not sure what the limit of set size is
#so may have problems with large surfaces    
	
    a=set(q)
    b=set(d_verts)
    d=a-b

    if bpy.ops.object.mode_set.poll():
        print('mode_set = EDIT')
        bpy.ops.object.mode_set(mode = 'EDIT')
    
    if bpy.ops.mesh.select_all.poll():
        print('action = DESELECT')
        bpy.ops.mesh.select_all(action = 'DESELECT')

    if bpy.ops.object.mode_set.poll():
        print('mode_set = OBJECT')
        bpy.ops.object.mode_set(mode = 'OBJECT')

    for v in d:
        me.vertices[v].select = True

    if bpy.ops.object.mode_set.poll():
        print('mode_set = EDIT')
        bpy.ops.object.mode_set(mode = 'EDIT')
    
    if bpy.ops.mesh.delete.poll():
        print('Deleting Vertices')
        bpy.ops.mesh.delete()
    
    if bpy.ops.object.editmode_toggle.poll():
        bpy.ops.object.editmode_toggle()
        
    me.update()
    sce.update()

def load_LandXML_points(filepath):
#parse the LandXML file
    node = xml.dom.minidom.parse(filepath)

    scene = bpy.context.scene
    scene.update()
    
    if bpy.ops.object.mode_set.poll():
        print('in load_XML mode_set = OBJECT')
        bpy.ops.object.mode_set(mode='OBJECT')
        

# Create the new mesh to feed in vertices:
    scene = bpy.context.scene
    mesh = bpy.data.meshes.new('')
    object = bpy.data.objects.new('LandXML vertices', mesh)
    scene.objects.link(object)

# Read in all points
    points=node.getElementsByTagName('CgPoint')

    r=mesh.vertices
    r.add(len(points))
    idx=0
    for p in points:
        for coordset in p.childNodes:
            xyz_list=coordset.data.strip()
            xyz_coord=xyz_list.split(' ')
            x_coord=float(xyz_coord[1])
            y_coord=float(xyz_coord[0])
            z_coord=float(xyz_coord[2])
#            operator.report({'WARNING'}, "read in vtx %f %f %f" % (x_coord,y_coord,z_coord))
            coord=(x_coord, y_coord, z_coord)
            r[idx].co=coord
            idx=idx+1

        
    scene.update()
    mesh.update() 
    object.select=True
    bpy.ops.object.origin_set(type='ORIGIN_GEOMETRY', center='MEDIAN')
    scene.update()
    return None



def load(operator, context, filepath=""):

    try:
        load_LandXML_points(filepath)
    except (xml.parsers.expat.ExpatError, UnicodeEncodeError) as e:
        import traceback
        traceback.print_exc()

        operator.report({'WARNING'}, "Unable to parse XML, %s:%s for file %r" % (type(e).__name__, e, filepath))
        return {'CANCELLED'}

    return {'FINISHED'}